Skip to contents

Immediately outputs an warning without the call as part of the error message that as far as possible is a single line.

Usage

wrn(...)

Arguments

...

zero or more objects which can be coerced to character

See also